Index: src/arm64/macro-assembler-arm64.cc |
diff --git a/src/arm64/macro-assembler-arm64.cc b/src/arm64/macro-assembler-arm64.cc |
index c7a61ea67a41830e9b2249b991c005ed421b3650..82f718319c709beefc48e5e4391677e7fe4dc6e2 100644 |
--- a/src/arm64/macro-assembler-arm64.cc |
+++ b/src/arm64/macro-assembler-arm64.cc |
@@ -4213,10 +4213,11 @@ void MacroAssembler::LoadFromNumberDictionary(Label* miss, |
} |
Bind(&done); |
// Check that the value is a normal property. |
const int kDetailsOffset = |
SeededNumberDictionary::kElementsStartOffset + 2 * kPointerSize; |
Ldrsw(scratch1, UntagSmiFieldMemOperand(scratch2, kDetailsOffset)); |
+ DCHECK_EQ(FIELD, 0); |
TestAndBranchIfAnySet(scratch1, PropertyDetails::TypeField::kMask, miss); |
// Get the value at the masked, scaled index and return. |
@@ -4213,10 +4213,11 @@ void MacroAssembler::LoadFromNumberDictionary(Label* miss, |
} |
Bind(&done); |
- // Check that the value is a normal property. |
+ // Check that the value is a field property. |
const int kDetailsOffset = |
SeededNumberDictionary::kElementsStartOffset + 2 * kPointerSize; |